<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>CommandLineFocus</name>
    <message>
        <location filename="../CommandLineFocusInit.js" line="+2"/>
        <source>&amp;Focus on Command Line</source>
        <translation type="unfinished">&amp;Skočit na příkazový řádek</translation>
    </message>
</context>
</TS>
